#!/bin/csh -f

## Script to web-get a batch of gfs4 grib2 data
##
## Usage: There are two options for using this script:
##
## Option 1: csh wget_GFS.csh 24 2014070100
##   - this option will grab 24 hours of forecast data starting on Jul 1, 2014 00z
##
## Option 2: csh wget_GFS.csh 24 12
##   - this option will grab today's 24 forecast starting at 12z
##
## Adapted: WRF-Hydro team...July 2014

if($#argv < 2) then
  echo "Usage: $0 fcstLen HH/ymdh"
  exit
endif
set fcstLen = "$1"
set HH = "$2"
@ fcstLen = $fcstLen + 1

if($#argv == 3) then
   set Lag = "$3"
else
   set Lag = 0 
endif

set option = ""
set WGET = "wget"
set URL = "http://nomads.ncdc.noaa.gov/data/gfs4"


if($HH < 72 ) then
   set date = `date -u +%y%m%d`
   set start_time = "20${date}${HH}"
   if($Lag != 0) then
      set start_time = `perl $SYSHOME/REALTIME/bin/PERL/advance_cymdh.pl ${start_time} -24`
   endif
else
   set start_time = "$HH"
endif


echo "start geting NAM218 from NOAA at $start_time $fcstLen hr."

set ymd = `echo $start_time|cut -c1-8`
set ym = `echo $start_time|cut -c1-6`
set cycle = `echo $start_time|cut -c9-10`

set count = 0

echo "current working directory is :"
pwd 

while($count < $fcstLen)
   set end_time = `perl $SYSHOME/REALTIME/bin/PERL/advance_cymdh.pl ${start_time} $count`
   set hh = `echo $end_time|cut -c9-10` 
   if($count <10) then
     set fcst = "00$count"   
   else
     if($count < 100) then
        set fcst = "0$count"   
     endif
   endif

   ${WGET} ${option} ${URL}/${ym}/${ymd}/gfs_4_${ymd}_0000_${fcst}.grb2	

   @ count = $count + 1
end
